unit fonctions_ibx;

{$IFDEF FPC}
{$MODE Delphi}
{$ENDIF}

interface

uses
  Classes, SysUtils,
  {$IFDEF VERSIONS}
  fonctions_version,
  {$ENDIF}
  IB,
  IBSQL,
  IBCustomDataSet,
  IBDatabase,
  db;

const
  DEFAULT_FIREBIRD_SERVER_DIR = '/var/lib/firebird/2.5/';
  CST_FBLIB = 'lib';
  CST_FB    = 'fb';
  CST_FBCLIENT = CST_FB+'client';
  CST_FB64 = '64';
  CST_FB32 = '32';
  CST_FBVERSION2 = '.2';
  CST_FBISQL = {$IFDEF WINDOWS}
               'isql.exe';
               {$ELSE}
               'isql-fb';
               {$ENDIF}

  CST_FBISQL_SUB = {$IFDEF WINDOWS}
               'isql'{$IFDEF CPU64}+CST_FB64{$ENDIF}+'.exe';
               {$ELSE}
               CST_FBISQL{$IFDEF CPU64}+CST_FB64{$ENDIF};
               {$ENDIF}

               {$IFDEF VERSIONS}
               gver_fonctions_ibx : T_Version = ( Component : 'IBX Connect package.' ;
                                                  FileUnit : 'fonctions_ibx' ;
                                       		  Owner : 'Matthieu Giroux' ;
                                       		  Comment : 'Just add the package.' ;
                                       		  BugsStory   : 'Version 1.0.2.0 : function fs_AddFieldNameIfNotNull.'
                                                              + 'Version 1.0.1.0 : Upgrading to fb32 and fb64 directory.'
                                                              + 'Version 1.0.0.0 : Creating unit from fonctions_startibx.';
                                       		  UnitType : 1 ;
                                       		  Major : 1 ; Minor : 0 ; Release : 2 ; Build : 0 );
               {$ENDIF}

var
   gb_ibxembed : Boolean = False;

 {$IFDEF FPC}
 procedure p_setLibrary (var libname: string);
 {$ENDIF}
 procedure p_DatasetCancelUpdatesIfEdited ( const AIBDataset : TIBCustomDataSet );
procedure setBaseParams ( const ADatabase : TIBDataBase; const AUserName,APassWord,ARoleName,Alc_type:string);
function fs_AddFieldNameIfNotNull ( const AField : ISQLData; const as_TextMaybeAdd : String ):String;

implementation

uses fonctions_system,
     fonctions_db,
     LazFileUtils,
     fonctions_dbobjects;

procedure p_DatasetCancelUpdatesIfEdited ( const AIBDataset : TIBCustomDataSet );
Begin
  with AIBDataset do
   if State in [dsEdit,dsInsert] then
    CancelUpdates;
end;

function fs_AddFieldNameIfNotNull ( const AField : ISQLData; const as_TextMaybeAdd : String ):String;
Begin
  with AField do
  if IsNull
   Then Result:=''
   Else
     if SQLType in [SQL_TYPE_DATE, SQL_TYPE_TIME, SQL_TIMESTAMP, SQL_TEXT, SQL_VARYING, SQL_BLOB, SQL_ARRAY, SQL_QUAD ]
      Then Result:= as_TextMaybeAdd+''''+fs_stringDbQuote(AField.AsString)+''''
      Else Result:= as_TextMaybeAdd+AField.AsString;
end;

{$IFDEF FPC}
procedure p_setLibrary (var libname: string);
var LAppDir : String;
const cst_usr_lib = '/usr/lib/';
Begin
  LAppDir:=GetAppDir;
  {$IFDEF WINDOWS}
  {$IFDEF CPU64}
  gb_ibxembed := FileExistsUTF8(LAppDir+{$IFNDEF WINDOWS}CST_FBLIB+{$ENDIF}CST_FBCLIENT+CST_FB64+CST_EXTENSION_LIBRARY);
  if gb_ibxembed
   Then libname:= {$IFNDEF WINDOWS}LAppDir+CST_FBLIB+{$ENDIF}CST_FBCLIENT+CST_FB64+CST_EXTENSION_LIBRARY
   Else
  {$ENDIF}
     libname:= {$IFNDEF WINDOWS}LAppDir+CST_FBLIB+{$ENDIF}CST_FBCLIENT+CST_EXTENSION_LIBRARY;
  {$ELSE}
  {$IFNDEF DARWIN}
  gb_ibxembed:= FileExistsUTF8(LAppDir+CST_FBLIB + CST_FBCLIENT  + CST_EXTENSION_LIBRARY + CST_FBVERSION2)
                or     (    ( pos ( DEFAULT_FIREBIRD_SERVER_DIR, gs_DefaultDatabase ) <> 1 )
                        and ( gs_DefaultDatabase <> '' )
                        and (   ( gs_DefaultDatabase [1] = '/' )));
  if gb_ibxembed
   Then libname := LAppDir + CST_FBLIB + CST_FBCLIENT  + CST_EXTENSION_LIBRARY + CST_FBVERSION2 + ':' + CST_FBLIB + CST_FBCLIENT  + CST_EXTENSION_LIBRARY + '.2'
   Else
     Begin
      gb_ibxembed:= FileExistsUTF8(ExtractSubDir(LAppDir)+CST_FB{$IFDEF CPU64}+CST_FB64{$ELSE}+CST_FB32{$ENDIF}+DirectorySeparator+CST_FBLIB + CST_FBCLIENT  + CST_EXTENSION_LIBRARY + CST_FBVERSION2)
                    or     (    ( pos ( DEFAULT_FIREBIRD_SERVER_DIR, gs_DefaultDatabase ) <> 1 )
                            and ( gs_DefaultDatabase <> '' )
                            and (   ( gs_DefaultDatabase [1] = '/' )));
      if gb_ibxembed
       Then Begin LAppDir := ExtractSubDir(LAppDir)+CST_FB{$IFDEF CPU64}+CST_FB64{$ELSE}+CST_FB32{$ENDIF}+DirectorySeparator; libname := LAppDir + CST_FBLIB + CST_FBCLIENT  + CST_EXTENSION_LIBRARY + CST_FBVERSION2 + ':' + CST_FBLIB + CST_FBCLIENT  + CST_EXTENSION_LIBRARY + '.2'; End
       Else libname := CST_FBLIB + CST_FBCLIENT + CST_EXTENSION_LIBRARY + CST_FBVERSION2;
    End;

  {$ENDIF}
  {$ENDIF}
  {$IFNDEF WINDOWS}
  if FileExistsUTF8(LAppDir+'exec.sh') Then
     fs_ExecuteProcess('sh',' "'+LAppDir+'exec.sh"');
  {$ENDIF}
end;
{$ENDIF}

procedure setBaseParams ( const ADatabase : TIBDataBase; const AUserName,APassWord,ARoleName,Alc_type:string);
Begin
  with ADatabase,Params do
   Begin
     Clear;
     Add('user_name='+AUserName);
     Add('password='+APassWord);
     if Alc_type > '' Then
       Add('lc_ctype='+Alc_type);
//     DefaultCharSetName:=Alc_type;
     if ARoleName>'' then
       Add('sql_role_name='+ARoleName);
   end;
end;


{$IFDEF VERSIONS}
initialization
p_ConcatVersion ( gver_fonctions_ibx );
{$ENDIF}
end.

